<?PHP
//
// ZendTo
// Copyright (C) 2006 Jeffrey Frey, frey at udel dot edu
// Copyright (C) 2018 Julian Field, Jules at Zend dot To
//
// Based on the original PERL dropbox written by Doke Scott.
// Developed by Julian Field.
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
//

//
// This file contains all the non-user interface parts of the ZendTo
// configuration.
// Before editing this file, read
//     https://zend.to/preferences.php
// as it will tell you what everything does, and lists all the settings
// you *must* change for it to work on your site.
// After that, look for the strings "soton", "ECS" and "152" to be sure
// you don't miss anything.
//

define('NSSDROPBOX_BASE_DIR','/opt/zendto/');
define('NSSDROPBOX_LIB_DIR', '/opt/zendto/lib/');
define('NSSDROPBOX_DATA_DIR','/var/zendto/');

// This defines the version number, please do not change
define('ZTVERSION','5.12-8');

// Is this ZendTo or MyZendTo?
define('MYZENDTO','FALSE');

// This is for gathering nightly stats, see docs about RRD and root's crontab
define('RRD_DATA_DIR',NSSDROPBOX_DATA_DIR.'rrd/');
define('RRD_DATA',RRD_DATA_DIR.'zendto.rrd');
define('RRDTOOL','/usr/bin/rrdtool');

// This sets which Database engine you are using, either 'SQLite' or 'SQLite3'
// or 'MySQL'. If you are using SQLite on Ubuntu 12 (and higher) servers, be
// sure to specify 'SQLite3' and not 'SQLite'.
// It must look like one of these 3 examples:
// define('SqlBackend', 'SQLite');
// define('SqlBackend', 'SQLite3');
// define('SqlBackend', 'MySQL');
// SQLite3 is the easiest to use and works on everything except RHEL/CentOS 5.
// SQLite3 requires no database setup at all.
define('SqlBackend', 'SQLite3');

//
// Preferences are stored as a hashed array.  Inline comments
// indicate what everything is for.
//
$NSSDROPBOX_PREFS = array(

  // Next line needed for SQLite operation
  'SQLiteDatabase'       => NSSDROPBOX_DATA_DIR."zendto.sqlite",

  // Next 4 lines needed for MySQL operation
  'MySQLhost'            => 'localhost',
  'MySQLuser'            => 'zendto',
  'MySQLpassword'        => 'zendto',
  'MySQLdb'              => 'zendto',

  // This is where your drop-offs are stored.
  // It must be on the same filesystem as /var/zendto/incoming, and
  // on preferably on the same filesystem as /var/zendto.
  'dropboxDirectory'     => NSSDROPBOX_DATA_DIR."dropoffs",

  // This is where ZendTo writes its own log, visible to admins on
  // the web interface.
  // This used to be in NSSDROPBOX_DATA_DIR/zendto.log.
  // As of 5.12-1 I have moved it to /var/log/zendto/zendto.log,
  // and logrotate will now take care of its log rotation.
  // If your setting is still NSSDROPBOX_DATA_DIR/zendto.log, you
  // just need to change it here to /var/log/zendto/zendto.log and
  // the log rotation will happen automatically.
  'logFilePath'          => "/var/log/zendto/zendto.log",

  // The root URL of the ZendTo web app in your organisation.
  // Make this "https" if you can.
  // It must end with a "/".
  'serverRoot'           => 'http://zendto.soton.ac.uk/',

  // Keep drop-offs for x days before auto-deleting them.
  'numberOfDaysToRetain' => 14,

  // If someone sends a request for a Drop-off, how long does the
  // recipient have to reply?
  // After this time has passed, the request is disabled & deleted.
  // It is measured in seconds (3600 = 1 hour, 86400 = 1 day)
  'requestTTL'           => 604800, // 1 week

  // If no-one has picked up a dropoff x days before it's going to be
  // auto-deleted, start hassling the recipients daily about it.
  // Set this to 0 to disable it.
  'warnDaysBeforeDeletion' => 0,

  // The max size for an entire drop-off,
  'maxBytesForDropoff'   => 21474836480, // 20 GBytes = 20*1024*1024*1024
  // and the max size for each individual file in a drop-off
  'maxBytesForFile'      => 21474836480, // 20 GBytes = 20*1024*1024*1024

  // What language do you want ZendTo to run in?
  // These are locale codes (output from "locale -a" will show what are
  // available on your system currently) like 'en_GB' and 'pt_BR' and so on.
  // To add or change any text shown by ZendTo, please take a look at
  // https://zend.to/translators.php.
  // If you are just working in English then you can change the text by
  // adding a "translation" for the appropriate phrase to the en_US
  // translation (which is blank by default).
  // Also, don't forget that you can change simple stuff like the name
  // of your company in zendto.conf, to save you mucking with translations
  // at all.
  // The default language is 'en_US'.
  'language'             => 'en_US',

  // What is the list of valid languages your users can choose from,
  // and in what order does the list appear?
  'languageList' => array('de_DE Deutsch', 'en_GB English (UK)', 'en_US English (US)', 'es_ES Espa&ntilde;ol', 'fr_FR Fran&ccedil;ais', 'it_IT Italiano', 'nl_NL Nederlands', 'pt_BR Portugu&ecirc;s (BR)'),

  // If you are in the EU, you really should show a consent box to
  // ensure the user understands that the site is (1) storing a cookie
  // (albeit only a session cookie), and (2) will store their email address
  // and name in order to talk to the sender/recipients of the drop-off.
  // This is for EU GDPR purposes.
  'cookieGDPRConsent'    => FALSE,

  // Do you want to hide the fact that ZendTo is written in PHP?
  // Setting this to TRUE will remove all ".php" extensions from the
  // links within ZendTo and the emails it sends. Links which still
  // have ".php" in them will still work. To set this to TRUE, you must
  // add the following lines to the start of each "VirtualHost" in your
  // Apache config files. These files have "zendto" in their name and
  // are located in one of these directories, depending on your Linux:
  //   /etc/httpd/conf.d
  //   /etc/apache2/sites-available
  //   /etc/apache2/vhosts.d
  // The lines to be added at/near the start of the VirtualHost are:
  //   <IfModule mod_rewrite.c>
  //     RewriteEngine on
  //     RewriteCond %{REQUEST_FILENAME} !-d
  //     RewriteCond %{REQUEST_FILENAME}\.php -f
  //     RewriteRule ^(.*)$ $1.php
  //   </IfModule>
  // After changing any Apache config file, you will need to restart
  // Apache with one of these commands, depending on your Linux:
  //   service httpd restart
  //   systemctl restart httpd
  //   systemctl restart apache2
  'hidePHP' => FALSE,

  // Usually, your internal (logged-in) users can change the name of their
  // "organization" that is used in new drop-offs. That is very useful for
  // places such as universities where your users might be doing work on
  // behalf of another orgnization while using university-supplied services.
  // Set this to TRUE to bypass this form completely, which makes the
  // drop-off process a lot quicker and simpler.
  // Note: This does *not* change the process for external users at all.
  'skipSenderInfo'       => TRUE,

  // Do you want recipients to be able to see the details of the other
  // recipients and who has picked up the drop-off and from where?
  'showRecipsOnPickup'   => FALSE,

  // The unique code for a request is either three 3- or 4-letter words,
  // or three 3-digit numbers (with leading zeros).
  // Use either 'words' or 'numbers'
  'wordlist'             => 'numbers',

  // When files are submitted in response to a request, you might want to
  // over-ride the recipient's email address to force the "files have been
  // dropped off for you" emails to go into your ticketing system's email
  // engine for automatic ticket assignment, rather than being sent to the
  // customer support rep who sent the request
  'requestTo'            => '', // Set to '' to disable this override

  // Allow external users (who can't login) to upload files?
  // Regardless of this setting, they always can if they've been given
  // a request code.
  // Setting this to FALSE stops external users sending files that
  // the recipient had not asked for.
  'allowExternalUploads' => TRUE,

  // You should check that senders who are not members of your organisation
  // (and so cannot login to ZendTo) are really the owner of the email
  // address they are sending from. So when they try to send you files,
  // you have some confidence they are who they say they are.
  // However, some sites are only expecting files from occasional people,
  // and don't want the senders to have to do the extra step.
  // Setting this to FALSE disables the email address confirmation step.
  'confirmExternalEmails' => TRUE,

  // Do you want to allow your own users to log in to ZendTo when they
  // are not connected to your local internal network.
  'allowExternalLogins'   => TRUE,

  // If a user fails to login with the correct password 'loginFailMax' times
  // in a row within 'loginFailTime' seconds, then the user is locked out
  // until the time period has passed.  86400 seconds = 1 day.
  // That means that if you fail to log in successfully 10 times in a row in
  // 1 day, your account is locked out for 1 day and you won't be able to
  // log in for that day.
  'loginFailMax'          => 10,
  'loginFailTime'         => 86400,

  // Do you want to restrict downloads to humans only? If this is false,
  // you may get a Denial of Service attack as anyone with the URL to
  // reach a file can download it, even malicious people. So someone can
  // command a botnet to download the same file 1,000,000 million times
  // simultaneously. Bad news for your server!
  // If this is true, unauthorised users trying to download a file have
  // to prove they are a real person and not a program.
  'humanDownloads'       => TRUE,

  // When a user sends a new drop-off, do you want them to be able to
  // use the "email recipients" tick box?
  'allowEmailRecipients' => TRUE,

  // When a user sends a new drop-off, do you want them to be able to
  // use the "email the Passcode as well as the Claim ID" tick box?
  'allowEmailPasscode'   => TRUE,

  // When a user sends a new drop-off, do you want the "email the
  // Passcode as well as the Claim ID" tick box to be ticked by default?
  'defaultEmailPasscode' => TRUE,

  // Maximum length of a submitted Request Subject, and Short Note
  'maxSubjectLength'     => 100,
  'maxNoteLength'        => 1000,

  // ***********************
  // **** Customise me! ****
  // ***********************
  // This lists all the network numbers (class A, B and/or C) which your
  // site uses. Users coming from here will be considered "local" which
  // can be used to affect the user interface they get. If they visit ZendTo
  // from a "local" IP address, they are strongly encouraged to login
  // before trying to drop off files or use ZendTo.
  // These are the values for the University of Southampton.
  // Replace the contents of this array with a list of the network prefixes
  // you use for your site.
  'localIPSubnets'       => array('152.78','10.','192.168.'),

  // ***********************
  // **** Customise me! ****
  // ***********************
  // The file specified here (full path starting with '/') contains
  // the list of the email domain names used by any of your
  // "internal" users. People from outside your organisation (who
  // cannot login) will only be able to send drop-offs to people
  // whose email addresses are in 1 or more of these domains.
  //
  // The file will contain a list of domain names, one per line.
  // Blank lines and comment lines starting wth '#' will be ignored.
  // If, for example, a line contains "my-company.com" then the list of
  // recipient email domains for un-authenticated users will contain
  // "my-company.com" and "*.my-company.com".
  //
  // For backward compatibility reasons, this can also be a regular
  // expression defining the set of valid domain names. In this case,
  // it must start *and* end with a '/'.
  // This example matches "soton.ac.uk" and "*.soton.ac.uk".
  // 'emailDomainRegexp' => '/^([a-zA-Z\.\-]+\.)?soton\.ac\.uk$/i',
  'emailDomainRegexp' => '/opt/zendto/config/internaldomains.conf',

  //
  // Data Integrity and Encryption
  //
  // The max size for a drop-off to have checksums calculated.
  // Disable this feature by setting the value to 0.
  'maxBytesForChecksum'  => 314572800, // 300 MBytes = 300*1024*1024

  // The max size for a drop-off to be encrypted
  // Disable this feature by setting the value to 0.
  'maxBytesForEncryption' => 314572800, // 300 MBytes = 300*1024*1024

  // Enforce encryption. This stops the user disabling it, and also
  // makes it ignore the maxBytesForEncryption size above.
  'enforceEncryption' => FALSE,

  // The minimum length of the passphrase a user can enter when using
  // encryption.
  // Don't worry about wanting capitals, digits and emoji in a passphrase.
  // A better defence is simply a much longer pass*phrase*, not a short
  // pass*word*.
  'minPassphraseLength' => 10,

  // How many times should you allow a wrong Passcode for a particular
  // pick-up attempt before auto-deleting the drop-off?
  // This helps protect against brute-force attacks on dropoff Passcodes.
  // Set it to 0 to disable this feature, but that will leave you open
  // to potential attack.
  'maxPickupFailures' => 50,

  // Do you want to disclose IP addresses in emails?
  // Yes if they are external ones, but possibly not if they are internal.
  'emailSenderIP' => TRUE,

  // When a user sends a new drop-off, do you want the sender to also
  // receive a copy of the email sent to the recipients? It will be a
  // Bcc copy of the message sent to the 1st recipient.
  'bccSender' => FALSE,

  // *If* bccSender is set to TRUE, do you want to send the Bcc to
  // external users outside your organisation, when they send a
  // new drop-off. Probably not.
  'bccExternalSender' => FALSE,

  // Do some of your users often need to send the same files to different
  // people over and over again?
  // Well, YOU WANT TO ENABLE THIS.
  //
  // It means they don't have to keep uploading the same files repeatedly,
  // nor do the individual copies for customers (recipients) take any
  // disk space.
  //
  // If you want to be able to optionally send files from a "library"
  // directory of frequently used files, set this to TRUE.
  // This will enable a user to either upload a file or pick one from
  // the library. The description used with the library file will be
  // whatever the last user set it to for that library file.
  // The extra bit of user interface will only appear for those users
  // who actively use the feature. All the rest of your users will never
  // know it is there.
  'usingLibrary' => FALSE,

  // This is the location of the library directory referred to above.
  // You might want to set up a WebDAV directory in your Apache web
  // server configuration, so that administrators can easily manage the
  // files in the library. Default points to /var/zendto/library.
  // The library should contain the files you want users to see in the
  // "new dropoff" form.
  // If you create subdirectories in here named the same as a username,
  // that user will see just the files in their subdirectory instead;
  // over-riding the files in the libraryDirectory itself.
  // If there are no files present, the library drop-down will not be
  // shown in the web user interface. Only the people that actually use it
  // will see it exists!
  // So by leaving libraryDirectory itself empty, but putting files in a
  // user's subdirectory, you can create a setup where only that user will
  // see any sign of there being a library.
  'libraryDirectory' => NSSDROPBOX_DATA_DIR."library",

  // *If* you do something like embed the whole of ZendTo in an iframe,
  // you may need to publicise a different URL for your installation
  // than the 'serverRoot' above which is the one that ZendTo itself
  // needs. So you will want a different one in the emails and
  // user-instructions that ZendTo sends.
  // Almost all sites can leave this set to '' as it will then use the
  // normal serverRoot defined above.
  // If defined and not '' this value will over-ride the serverRoot,
  // but only in email messagses and instructions to users.
  // If you use this feature, the URL must end with a '/'.
  'advertisedServerRoot' => '',

  // This only affects users of MyZendTo (very few people).
  // When using MyZendTo, there is a default value for the storage quota
  // each user has. This means you only have to add users with bin/adduser.php
  // and maintain their quota with bin/setquota.php when the default quota
  // is not right for them. This saves an awful lot of administrative work,
  // as you do not have to match your local user table in MySQL/SQLite with
  // all the users that can authenticate with AD/IMAP/LDAP and so on.
  // Value in bytes.
  'defaultMyZendToQuota' => 100000000, // 100 Mbytes

  // There are 2 CAPTCHAs available:
  // 1. The much improved Google reCAPTCHA v2, OR
  // # NO LONGER AVAILABLE 2. The AreYouAHuman CAPTCHA,
  // OR you can choose to disable the CAPTCHA altogether. If you do this
  //    it will be possible for bad people to attack your ZendTo website
  //    and send anyone in your organisation any malicious file they like.
  // The setting below must be one of 'google' or 'disabled'.
  'captcha' => 'google',

  //
  // Settings for the Google reCAPTCHA
  //
  // Get these 2 values from
  // https://www.google.com/recaptcha/admin
  'recaptchaPublicKey'   => '--Google-reCAPTCHA-Site-key-goes-here---',
  'recaptchaPrivateKey'  => '--Google-reCAPTCHA-Secret-key-goes-here-',
  // Are we using the new "Invisible" Google reCAPTCHA?
  // To use this service you must sign up for it at
  // https://www.google.com/recaptcha/intro/comingsoon/invisible.html
  // (Get your site and secret keys above first!)
  // Note: July 2018 - The "Invisible" one appears to be causing some
  //                   problems right now. Leave this set to FALSE.
  'recaptchaInvisible'   => FALSE,

  // What language to use for the Invisible reCAPTCHA ?
  // This does NOT affect the VISIBLE one at all, that follows the
  // language chosen by the user.
  //
  // Note: these are **NOT** the same language codes that ZendTo uses!
  // Look it up here https://developers.google.com/recaptcha/docs/language
  // en = English (US)     en-GB = English (UK)
  // The default of ZendTo is US English. For British English, set this
  // to 'en-GB' and set the value of 'language' to 'en_GB'.
  'recaptchaLanguage'    => 'en-US',

  //
  // E-mail settings.
  //

  // the default email domain when just usernames are supplied
  'defaultEmailDomain' => 'soton.ac.uk',

  // There are 2 different ways you can send email messages.
  //
  // a) If you leave 'SMTPserver' set to '' then the old text-only
  //    method will be used (the PHP mail() function), and you will
  //    need to configure sendmail/Postfix yourself.
  //    NOTE: All the following SMTP settings will be ignored. This is to
  //          provide backward compatibility with existing installations.
  // OR
  // b) If you set 'SMTPserver' to the hostname or IP of your SMTP server,
  //    then PHPMailer will be used to send all mail to that server.
  //    PHPMailer has several advantages:
  //    1. Easier to setup (you've nearly done it)
  //    2. Can do STARTTLS for encryption
  //    3. Can authenticate to your SMTP server
  //    4. Can optionally send HTML versions of emails as well as the
  //       plain text ones.
  //       If any of these files in the templates directory exist:
  //          dropoff_email_html.tpl
  //          pickup_email_html.tpl
  //          request_email_html.tpl
  //          verify_email_html.tpl
  //       then both text and HTML versions of the relevant email are
  //       sent.
  //       These HTML email templates are optional. In each case, if it
  //       does not exist, just the plain text one will be used.
  //       Hint: If you want to include images in the HTML, embed them
  //             directly in the HTML code using a "data:image/..." URI.
  //             Then even recipients whose email app does not display
  //             remote images, will still display yours!
  //
  // Full hostname or IP address of your SMTP server
  // 'SMTPserver' => 'smtp.soton.ac.uk',
  'SMTPserver'   => '', // If blank, will use PHP mail(). See above.
  // SMTP port number. Usually 25, 465 or 587.
  'SMTPport'     => 25,
  // What encryption to use: must be '' (for no encryption) or 'tls'
  // (or 'ssl' which is deprecated)
  'SMTPsecure'   => 'tls',
  // Do you need to authenticate to your SMTP server?
  // If not, leave SMTPusername set to ''.
  // If you do, set the username and password.
  'SMTPusername' => '',
  'SMTPpassword' => '',
  // By default we will use the UTF-8 character set, so international
  // characters work better. The most common alternative is 'iso-8859-1'.
  // Note: This *must* be in upper case, or it has no effect!!
  'SMTPcharset'  => 'UTF-8',
  // Do you want debug output to appear on your ZendTo site?
  // BEWARE: Setting this to true will break most normal functionality
  // of your ZendTo server. So only use it when you are actually trying
  // to find a problem.
  // Once set to true, the only place you can test and debug SMTP
  // problems is by clicking the "Resend Drop-off" button from a drop-off
  // listed in your ZendTo Outbox.
  // Do *NOT* try to debug SMTP output by creating a new drop-off.
  'SMTPdebug'    => false,
  // Do you want the email messages to always come "From" the email
  // address set in zendto.conf? If so, set this to FALSE.
  // If you want, where it woudn't cause SPF/DKIM/DMARC problems, to
  // make the emails appear to come From the person who created the drop-off,
  // set this to TRUE.
  // If your SMTP server is running Exchange (or is Office 365), then you
  // should leave it set to FALSE.
  // Setting this to TRUE has helped a few people overcome spam detection
  // problems when delivering to GMail addresses.
  'SMTPsetFromToSender' => FALSE,

  // These are the usernames of the ZendTo administrators at your site.
  // Regardless of how you login, these must be all lower-case.
  'authAdmins'   => array('admin1','admin2','admin3'),

  // These usernames can only view the stats graphs, they cannot do other
  // admin functions. They can up and down load drop-offs, of course.
  // Regardless of how you login, these must be all lower-case.
  'authStats'    => array('view1','view2','view3'),

  //
  // Settings for the Local SQL-based authenticator.
  //
  // See the commands in /opt/zendto/bin and the ChangeLog to use this.
  'authenticator' => 'Local',

  //
  // Settings for the IMAP authenticator.
  //
  // If you work in a multi-domain site, where users authenticate by
  // entering their entire email address rather than just their username,
  // simply set 'authIMAPDomain' => '' and it will treat their full
  // email address as their username and then work as expected.
  //
  // To change the port add ":993" to the server name, to use SSL add "/ssl".
  // for other changes see flags for PHP function "imap_open" on php.net.
  // For example, recent versions of PHP try to use TLS where possible, so
  // if you are connecting to localhost then add "/novalidate-cert" on to the
  // end of your server name.
  // 'authenticator' => 'IMAP',
  'authIMAPServer' => 'mail.soton.ac.uk',
  'authIMAPDomain' => 'soton.ac.uk',
  'authIMAPOrganization' => 'University of Southampton',
  'authIMAPAdmins' => array(),

  //
  // Settings for the LDAP authenticator.
  //
  // 'authenticator'         => 'LDAP',
  // 'authLDAPBaseDN'        => 'OU=users,DC=soton,DC=ac,DC=uk',
  // 'authLDAPServers'       => array('ldap1.soton.ac.uk','ldap2.soton.ac.uk'),
  // 'authLDAPAccountSuffix' => '@soton.ac.uk',
  // 'authLDAPUseSSL'        => false,
  // 'authLDAPStartTLS'      => false,
  // 'authLDAPBindDn'        => 'o=MyOrganization,uid=MyUser',
  // 'authLDAPBindPass'      => 'SecretPassword',
  // 'authLDAPOrganization'  => 'My Organization',
  // 'authLDAPUsernameAttr'  => 'uid',
  // 'authLDAPEmailAttr'     => 'mail',
  // This is the list of LDAP properties used to build the user's full name
  // 'authLDAPFullName'      => 'givenName sn',
  // If both these 2 settings are set, then the users must be members of this
  // group/role.
  // 'authLDAPMemberKey'     => 'memberOf',
  // 'authLDAPMemberRole'    => 'cn=zendtoUsers,OU=securityGroups,DC=soton,DC=ac,DC=uk',

  //
  // Settings for the 2-forest/2-domain AD authenticator.
  // Set 
  //     'authLDAPServers2' => array(),
  // if you only have to search 1 AD forest/domain.
  //
  // For help getting these settings right, and how to test them, see
  // https://zend.to/activedirectory.php
  //
  // If you want to search for your user in multiple OUs in either or both
  // of the forests/domains, then make the authLDAPBaseDN1 (or 2) an array
  // of OUs, such as in this example:
  // 'authLDAPBaseDN1' => array('OU=Staff,DC=mycompany,DC=com', 'OU=Interns,DC=mycompany,DC=com'),
  // Of course the same works for 'authLDAPBaseDN2'.
  // Note: Never split a setting across 2 or more lines!
  //
  // 'authenticator'             => 'AD',
  'authLDAPServers1'          => array('ad1.ecs.soton.ac.uk','ad2.ecs.soton.ac.uk'),
  'authLDAPBaseDN1'           => 'OU=users,DC=ecs,DC=soton,DC=ac,DC=uk',
  'authLDAPAccountSuffix1'    => '@ecs.soton.ac.uk',
  // TLS will be used in preference to SSL, if enabled.
  'authLDAPUseSSL1'           => false,
  'authLDAPUseTLS1'           => false,
  'authLDAPBindUser1'         => 'SecretUsername1',
  'authLDAPBindPass1'         => 'SecretPassword1',
  'authLDAPOrganization1'     => 'ECS, University of Southampton',
  // If you are not using this 2nd set of settings for a 2nd AD forest,
  // do not comment them out, but instead set them to be empty.
  // Set 
  //     'authLDAPServers2' => array(),
  // if you only have to search 1 AD forest/domain.
  'authLDAPServers2'          => array('ad1.soton.ac.uk','ad2.soton.ac.uk'),
  'authLDAPBaseDN2'           => 'DC=soton,DC=ac,DC=uk',
  'authLDAPAccountSuffix2'    => '@soton.ac.uk',
  // TLS will be used in preference to SSL, if enabled.
  'authLDAPUseSSL2'           => false,
  'authLDAPUseTLS2'           => false,
  'authLDAPBindUser2'         => 'SecretUsername2',
  'authLDAPBindPass2'         => 'SecretPassword2',
  'authLDAPOrganization2'     => 'University of Southampton',

  // If both these 2 settings are set, then the users must be members of this
  // group/role. Please note this feature has not been rigorously tested yet.
  // 'authLDAPMemberKey'     => 'memberOf',
  // 'authLDAPMemberRole'    => 'cn=zendtoUsers,OU=securityGroups,DC=soton,DC=ac,DC=uk',

  //
  // Settings for the Multi authenticator.
  // This does not authenticate itself, but instead calls any combination
  // of the other authenticators in the order you list them.
  // The first authenticator that reports a username/password match will
  // be the one used for that session.
  // All the 'real' authenticators themselves are configured above as
  // normal.
  //
  // List the authenticator sequence as shown in this example:
  // 'authMultiAuthenticators' => array('IMAP', 'AD', 'Local'),
  //
  // 'authenticator' => 'Multi',
  'authMultiAuthenticators' => array('AD', 'Local'),

  // Regular expression defining a valid username for the Login page.
  // Usually no need to change this.
  'usernameRegexp'    => '/^([a-zA-Z0-9][a-zA-Z0-9\_\.\-\@\\\]*)$/i',

  // regular expression defining a valid email address for anyone.
  // Usually no need to change this.
  // Must look like /^(user)\@(domain)$/
  'validEmailRegexp' => '/^([a-zA-Z0-9][a-zA-Z0-9\.\_\-\+\&\']*)\@([a-zA-Z0-9][a-zA-Z0-9\_\-\.]+)$/i',

  'cookieName'        => 'zendto-session',
  // Get the value for the 'cookieSecret' from this command:
  // /opt/zendto/sbin/genCookieSecret.php
  'cookieSecret'      => '11111111111111111111111111111111',

  // This is the maximum lifetime of any ZendTo session cookie.
  //
  // If uploads that take a long time are not working, you need to
  // increase this value, along with the php.ini settings max_upload_time 
  // and max_run_time (which are also measured in seconds).
  //
  // Any upload taking longer than that will be killed.
  'cookieTTL'         => '43200', // 12 hours

  // Security HTTP headers
  //
  // Various HTTP headers are produced on every page ZendTo outputs, to
  // help protect you from various types of web-based attacks.
  // Note the value of each of these settings must be exactly right,
  // or they won't do anything. So don't guess the settings.
  // If you are not sure, leave them alone. Otherwise read the documentation
  // linked below.
  //
  // Also see you Apache configuration for ZendTo, as this adds the
  // "SameSite: strict" attribute to ZendTo's cookies, to help modern web
  // browsers protect you against CSRF attacks.
  //
  // https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/X-Frame-Options
  // This can be any of
  // 'deny' - denies any attempt to put ZendTo inside a <frame>, <iframe> or
  //          <object>.
  // 'sameorigin' - can only be put in a frame on the same origin as the page.
  // 'allow-from https://example.com/' - can only be put in a frame on the
  //                                     specified origin.
  // '' - do not send the X-Frame-Options header at all.
  'X-Frame-Options' => 'sameorigin',

  // The virus scanner uses ClamAV. You need to get clamav, clamav-db and
  // clamd installed (all available from RPMForge). If you cannot get the
  // permissions working, even after reading the documentation on
  // www.zend.to, then change the next line to '/usr/bin/clamscan --stdout'
  // and you will find it easier, though it will be a lot slower to scan.
  // If you need to disable virus scanning altogether, set this to 'DISABLED'.
  // Passing the '--fdpass' option to clamdscan speeds it up a lot!
  // The '--stdout' gets the ClamAV output into the ZendTo logfile.
  'clamdscan' => '/usr/bin/clamdscan --stdout --fdpass',
 
  // The command run to calculate the checksum of a file in a drop-off.
  // The (escaped+quoted) filename is appended to the end of this command.
  'checksum' => '/usr/bin/sha256sum --binary',

);

// ----                                        ---- //
// ---- DO NOT CHANGE ANYTHING BELOW THIS LINE ---- //
// ----                                        ---- //

// Do *not* change the next line. 
require_once(NSSDROPBOX_LIB_DIR.SqlBackend.'.php');

// IMPORTANT: Do not put extra spaces or lines after the PHP tag
//            just beneath this comment.
//            It will break dynamic/RRD images of your system stats.
?>
